@@ -10,16 +10,19 @@ class TCPLogstashHandler(SocketHandler, object):
     :param port: The port of the logstash server (default 5959).
     :param message_type: The type of the message (default logstash).
     :param fqdn; Indicates whether to show fully qualified domain name or not (default False).
-    :param version: version of logstash event schema (default is 0).
     :param tags: list of tags for a logger (default is None).
+    :param limit_stacktrace: limit characters for stacktraces
+    :param limit_string_fields: limit characters for string fields
+    :param limit_containers: limit length of containers (dict, list, set)
     """
 
-    def __init__(self, host, port=5959, message_type='logstash', tags=None, fqdn=False, version=0):
+    def __init__(self, host, port=5959, message_type='logstash', tags=None, fqdn=False,
+                 limit_stacktrace=0, limit_string_fields=0, limit_containers=0):
         super(TCPLogstashHandler, self).__init__(host, port)
-        if version == 1:
-            self.formatter = formatter.LogstashFormatterVersion1(message_type, tags, fqdn)
-        else:
-            self.formatter = formatter.LogstashFormatterVersion0(message_type, tags, fqdn)
+
+        self.formatter = formatter.LogstashFormatter(message_type, tags, fqdn, limit_stacktrace=limit_stacktrace,
+                                                     limit_string_fields=limit_string_fields,
+                                                     limit_containers=limit_containers)
 
     def makePickle(self, record):
         return self.formatter.format(record) + b'\n'
